LlvmBundleTryBuilder

Struct LlvmBundleTryBuilder 

pub(super) struct LlvmBundleTryBuilder<ExecutionEngineBuilder_: for<'this> FnOnce(&'this Context) -> Result<ExecutionEngine<'this>, Error_>, Error_> {
    pub(super) context: Context,
    pub(super) execution_engine_builder: ExecutionEngineBuilder_,
}
A more verbose but stable way to construct self-referencing structs. It is comparable to using StructName { field1: value1, field2: value2 } rather than StructName::new(value1, value2). This has the dual benefit of making your code both easier to refactor and more readable. Call try_build() or try_build_or_recover() to construct the actual struct. The fields of this struct should be used as follows:

FieldSuggested Use
contextDirectly pass in the value this field should contain
execution_engine_builderUse a function or closure: (context: &_) -> Result<execution_engine: _, Error_>

Fields

context: Contextexecution_engine_builder: ExecutionEngineBuilder_

Implementations

Source

impl<ExecutionEngineBuilder_: for<'this> FnOnce(&'this Context) -> Result<ExecutionEngine<'this>, Error_>, Error_> LlvmBundleTryBuilder<ExecutionEngineBuilder_, Error_>

pub(super) fn try_build(self) -> Result<LlvmBundle, Error_>

Calls LlvmBundle::try_new() using the provided values. This is preferable over calling try_new() directly for the reasons listed above.

pub(super) fn try_build_or_recover(self) -> Result<LlvmBundle, (Error_, Heads)>

Calls LlvmBundle::try_new_or_recover() using the provided values. This is preferable over calling try_new_or_recover() directly for the reasons listed above.