#[repr(transparent)]pub(super) struct LlvmBundle {
actual_data: MaybeUninit<LlvmBundleInternal>,
}Expand description
The self-referencing struct.
Fields
actual_data: MaybeUninit<LlvmBundleInternal>Implementations
Sourceimpl LlvmBundle
impl LlvmBundle
Sourcepub(super) fn new(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> ExecutionEngine<'this>,
) -> LlvmBundle
pub(super) fn new( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> ExecutionEngine<'this>, ) -> LlvmBundle
Constructs a new instance of this self-referential struct. (See also LlvmBundleBuilder::build()). Each argument is a field of the new struct. Fields that refer to other fields inside the struct are initialized using functions instead of directly passing their value. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> execution_engine: _ |
Sourcepub(super) async fn new_async(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = ExecutionEngine<'this>> + 'this>>,
) -> LlvmBundle
pub(super) async fn new_async( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = ExecutionEngine<'this>> + 'this>>, ) -> LlvmBundle
Constructs a new instance of this self-referential struct. (See also LlvmBundleAsyncBuilder::build()). Each argument is a field of the new struct. Fields that refer to other fields inside the struct are initialized using functions instead of directly passing their value. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> execution_engine: _ |
Sourcepub(super) async fn new_async_send(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = ExecutionEngine<'this>> + Send + 'this>>,
) -> LlvmBundle
pub(super) async fn new_async_send( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = ExecutionEngine<'this>> + Send + 'this>>, ) -> LlvmBundle
Constructs a new instance of this self-referential struct. (See also LlvmBundleAsyncSendBuilder::build()). Each argument is a field of the new struct. Fields that refer to other fields inside the struct are initialized using functions instead of directly passing their value. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> execution_engine: _ |
Sourcepub(super) fn try_new<Error_>(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Result<ExecutionEngine<'this>, Error_>,
) -> Result<LlvmBundle, Error_>
pub(super) fn try_new<Error_>( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Result<ExecutionEngine<'this>, Error_>, ) -> Result<LlvmBundle, Error_>
(See also LlvmBundleTryBuilder::try_build().) Like new, but builders for self-referencing fields can return results. If any of them fail, Err is returned. If all of them succeed, Ok is returned. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> Result<execution_engine: _, Error_> |
Sourcepub(super) fn try_new_or_recover<Error_>(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Result<ExecutionEngine<'this>, Error_>,
) -> Result<LlvmBundle, (Error_, Heads)>
pub(super) fn try_new_or_recover<Error_>( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Result<ExecutionEngine<'this>, Error_>, ) -> Result<LlvmBundle, (Error_, Heads)>
(See also LlvmBundleTryBuilder::try_build_or_recover().) Like try_new, but all head fields are returned in the case of an error. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> Result<execution_engine: _, Error_> |
Sourcepub(super) async fn try_new_async<Error_>(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + 'this>>,
) -> Result<LlvmBundle, Error_>
pub(super) async fn try_new_async<Error_>( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + 'this>>, ) -> Result<LlvmBundle, Error_>
(See also LlvmBundleAsyncTryBuilder::try_build().) Like new, but builders for self-referencing fields can return results. If any of them fail, Err is returned. If all of them succeed, Ok is returned. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> Result<execution_engine: _, Error_> |
Sourcepub(super) async fn try_new_or_recover_async<Error_>(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + 'this>>,
) -> Result<LlvmBundle, (Error_, Heads)>
pub(super) async fn try_new_or_recover_async<Error_>( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + 'this>>, ) -> Result<LlvmBundle, (Error_, Heads)>
(See also LlvmBundleAsyncTryBuilder::try_build_or_recover().) Like try_new, but all head fields are returned in the case of an error. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> Result<execution_engine: _, Error_> |
Sourcepub(super) async fn try_new_async_send<Error_>(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + Send + 'this>>,
) -> Result<LlvmBundle, Error_>
pub(super) async fn try_new_async_send<Error_>( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + Send + 'this>>, ) -> Result<LlvmBundle, Error_>
(See also LlvmBundleAsyncSendTryBuilder::try_build().) Like new, but builders for self-referencing fields can return results. If any of them fail, Err is returned. If all of them succeed, Ok is returned. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> Result<execution_engine: _, Error_> |
Sourcepub(super) async fn try_new_or_recover_async_send<Error_>(
context: Context,
execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + Send + 'this>>,
) -> Result<LlvmBundle, (Error_, Heads)>
pub(super) async fn try_new_or_recover_async_send<Error_>( context: Context, execution_engine_builder: impl for<'this> FnOnce(&'this Context) -> Pin<Box<dyn Future<Output = Result<ExecutionEngine<'this>, Error_>> + Send + 'this>>, ) -> Result<LlvmBundle, (Error_, Heads)>
(See also LlvmBundleAsyncSendTryBuilder::try_build_or_recover().) Like try_new, but all head fields are returned in the case of an error. The arguments are as follows:
| Argument | Suggested Use |
|---|---|
context | Directly pass in the value this field should contain |
execution_engine_builder | Use a function or closure: (context: &_) -> Result<execution_engine: _, Error_> |
Sourcepub(super) fn with_context<'outer_borrow, ReturnType>(
&'outer_borrow self,
user: impl for<'this> FnOnce(&'outer_borrow Context) -> ReturnType,
) -> ReturnType
pub(super) fn with_context<'outer_borrow, ReturnType>( &'outer_borrow self, user: impl for<'this> FnOnce(&'outer_borrow Context) -> ReturnType, ) -> ReturnType
Provides limited immutable access to context. This method was generated because the contents of context are immutably borrowed by other fields.
Sourcepub(super) fn borrow_context<'this>(&'this self) -> &'this Context
pub(super) fn borrow_context<'this>(&'this self) -> &'this Context
Provides limited immutable access to context. This method was generated because the contents of context are immutably borrowed by other fields.
Sourcepub(super) fn with_execution_engine<'outer_borrow, ReturnType>(
&'outer_borrow self,
user: impl for<'this> FnOnce(&'outer_borrow ExecutionEngine<'this>) -> ReturnType,
) -> ReturnType
pub(super) fn with_execution_engine<'outer_borrow, ReturnType>( &'outer_borrow self, user: impl for<'this> FnOnce(&'outer_borrow ExecutionEngine<'this>) -> ReturnType, ) -> ReturnType
Provides an immutable reference to execution_engine. This method was generated because execution_engine is a tail field.
Sourcepub(super) fn borrow_execution_engine<'this>(
&'this self,
) -> &'this ExecutionEngine<'this>
pub(super) fn borrow_execution_engine<'this>( &'this self, ) -> &'this ExecutionEngine<'this>
Provides an immutable reference to execution_engine. This method was generated because execution_engine is a tail field.
Sourcepub(super) fn with_execution_engine_mut<'outer_borrow, ReturnType>(
&'outer_borrow mut self,
user: impl for<'this> FnOnce(&'outer_borrow mut ExecutionEngine<'this>) -> ReturnType,
) -> ReturnType
pub(super) fn with_execution_engine_mut<'outer_borrow, ReturnType>( &'outer_borrow mut self, user: impl for<'this> FnOnce(&'outer_borrow mut ExecutionEngine<'this>) -> ReturnType, ) -> ReturnType
Provides a mutable reference to execution_engine. This method was generated because execution_engine is a tail field. No borrow_execution_engine_mut function was generated because Rust’s borrow checker is currently unable to guarantee that such a method would be used safely.
Sourcepub(super) fn with<'outer_borrow, ReturnType>(
&'outer_borrow self,
user: impl for<'this> FnOnce(BorrowedFields<'outer_borrow, 'this>) -> ReturnType,
) -> ReturnType
pub(super) fn with<'outer_borrow, ReturnType>( &'outer_borrow self, user: impl for<'this> FnOnce(BorrowedFields<'outer_borrow, 'this>) -> ReturnType, ) -> ReturnType
This method provides immutable references to all tail and immutably borrowed fields.
Sourcepub(super) fn with_mut<'outer_borrow, ReturnType>(
&'outer_borrow mut self,
user: impl for<'this0, 'this1> FnOnce(BorrowedMutFields<'outer_borrow, 'this1, 'this0>) -> ReturnType,
) -> ReturnType
pub(super) fn with_mut<'outer_borrow, ReturnType>( &'outer_borrow mut self, user: impl for<'this0, 'this1> FnOnce(BorrowedMutFields<'outer_borrow, 'this1, 'this0>) -> ReturnType, ) -> ReturnType
This method provides mutable references to all tail fields.
Sourcepub(super) fn into_heads(self) -> Heads
pub(super) fn into_heads(self) -> Heads
This function drops all internally referencing fields and returns only the head fields of this struct.